@@ -153,4 +153,13 @@ typedef enum
   G_DESKTOP_VISUAL_BELL_FRAME_FLASH,
 } GDesktopVisualBellType;
 
+typedef enum
+{
+    G_DESKTOP_LOCATION_ACCURACY_LEVEL_COUNTRY,
+    G_DESKTOP_LOCATION_ACCURACY_LEVEL_CITY,
+    G_DESKTOP_LOCATION_ACCURACY_LEVEL_NEIGHBORHOOD,
+    G_DESKTOP_LOCATION_ACCURACY_LEVEL_STREET,
+    G_DESKTOP_LOCATION_ACCURACY_LEVEL_EXACT
+} GDesktopLocationAccuracyLevel;
+
 #endif /* __gdesktop_enums_h__ */
